@@ -20,17 +20,18 @@ from autoarray.operators.inversion.mappers import mapper as Mapper
 from autoarray.operators.transformer import TransformerDFT
 from autoarray.operators.transformer import TransformerFFT
 from autoarray.operators.transformer import TransformerNUFFT
-from autoarray.structures.arrays import Array
+from autoarray.structures.arrays import Array, Values
 from autoarray.structures.grids import (
     Grid,
-    GridIrregular,
+    GridIterate,
+    GridInterpolate,
     GridRectangular,
     GridVoronoi,
-    Coordinates,
+    GridCoordinates,
 )
 from autoarray.structures.kernel import Kernel
 from autoarray.structures.visibilities import Visibilities
 from autoarray.structures.arrays import MaskedArray
 from autoarray.structures.grids import MaskedGrid
 
-__version__ = '0.10.4'
+__version__ = '0.11.0'
