@@ -5,9 +5,30 @@ import numpy as np
 from autoarray.structures import arrays, grids
 
 
+def grid_from_mask_and_grid_class(
+    mask, grid_class, fractional_accuracy, sub_steps, pixel_scales_interp
+):
+
+    if grid_class is grids.Grid:
+
+        return grids.Grid.from_mask(mask=mask)
+
+    elif grid_class is grids.GridIterate:
+
+        return grids.GridIterate.from_mask(
+            mask=mask, fractional_accuracy=fractional_accuracy, sub_steps=sub_steps
+        )
+
+    elif grid_class is grids.GridInterpolate:
+
+        return grids.GridInterpolate.from_mask(
+            mask=mask, pixel_scales_interp=pixel_scales_interp
+        )
+
+
 class AbstractDataset:
-    def __init__(self, data, noise_map, name=None):
-        """A collection of abstract 2D for different data_type classes (an image, pixel-scale, noise-map, etc.)
+    def __init__(self, data, noise_map, positions=None, name=None):
+        """A collection of abstract 2D for different data_type classes (an image, pixel-scale, noise map, etc.)
 
         Parameters
         ----------
@@ -23,6 +44,7 @@ class AbstractDataset:
         """
         self.data = data
         self.noise_map = noise_map
+        self.positions = positions
         self._name = name if name is not None else "dataset"
 
     @property
@@ -69,8 +91,8 @@ class AbstractDataset:
     @property
     def absolute_signal_to_noise_map(self):
         """The estimated absolute_signal-to-noise_maps mappers of the image."""
-        return self.mapping.array_stored_1d_from_array_1d(
-            array_1d=np.divide(np.abs(self.data), self.noise_map)
+        return arrays.Array(
+            array=np.divide(np.abs(self.data), self.noise_map), mask=self.data.mask
         )
 
     @property
@@ -82,8 +104,8 @@ class AbstractDataset:
     def potential_chi_squared_map(self):
         """The potential chi-squared map of the imaging data_type. This represents how much each pixel can contribute to \
         the chi-squared map, assuming the model fails to fit it at all (e.g. model value = 0.0)."""
-        return self.mapping.array_stored_1d_from_array_1d(
-            array_1d=np.square(self.absolute_signal_to_noise_map)
+        return arrays.Array(
+            array=np.square(self.absolute_signal_to_noise_map), mask=self.data.mask
         )
 
     @property
@@ -97,31 +119,47 @@ class AbstractMaskedDataset:
         self,
         dataset,
         mask,
-        pixel_scale_interpolation_grid=None,
+        grid_class=grids.GridIterate,
+        grid_inversion_class=grids.Grid,
+        fractional_accuracy=0.9999,
+        sub_steps=None,
+        pixel_scales_interp=None,
         inversion_pixel_limit=None,
         inversion_uses_border=True,
     ):
 
+        if sub_steps is None:
+            sub_steps = [2, 4, 8, 16]
+
         self.dataset = dataset
         self.mask = mask
 
+        self.pixel_scales_interp = pixel_scales_interp
+
         ### GRIDS ###
 
         if mask.pixel_scales is not None:
 
-            self.grid = grids.MaskedGrid.from_mask(mask=mask)
+            self.grid = grid_from_mask_and_grid_class(
+                mask=mask,
+                grid_class=grid_class,
+                fractional_accuracy=fractional_accuracy,
+                sub_steps=sub_steps,
+                pixel_scales_interp=pixel_scales_interp,
+            )
 
-            if pixel_scale_interpolation_grid is not None:
-
-                self.pixel_scale_interpolation_grid = pixel_scale_interpolation_grid
-
-                self.grid = self.grid.new_grid_with_interpolator(
-                    pixel_scale_interpolation_grid=pixel_scale_interpolation_grid
-                )
+            self.grid_inversion = grid_from_mask_and_grid_class(
+                mask=mask,
+                grid_class=grid_inversion_class,
+                fractional_accuracy=fractional_accuracy,
+                sub_steps=sub_steps,
+                pixel_scales_interp=pixel_scales_interp,
+            )
 
         else:
 
             self.grid = None
+            self.grid_inversion = None
 
         self.inversion_pixel_limit = inversion_pixel_limit
         self.inversion_uses_border = inversion_uses_border
@@ -129,3 +167,7 @@ class AbstractMaskedDataset:
     @property
     def name(self) -> str:
         return self.dataset.name
+
+    @property
+    def positions(self):
+        return self.dataset.positions
