@@ -6,15 +6,15 @@ import copy
 from autoarray import exc
 from autoarray.dataset import abstract_dataset, preprocess
 from autoarray.mask import mask as msk
-from autoarray.structures import kernel, arrays
+from autoarray.structures import arrays, grids, kernel
 from autoarray.operators import convolver
 
 logger = logging.getLogger(__name__)
 
 
 class Imaging(abstract_dataset.AbstractDataset):
-    def __init__(self, image, noise_map, psf=None, name=None):
-        """A class containing the data, noise-map and point spread function of a 2D imaging dataset.
+    def __init__(self, image, noise_map, psf=None, positions=None, name=None):
+        """A class containing the data, noise map and point spread function of a 2D imaging dataset.
 
         Parameters
         ----------
@@ -26,7 +26,9 @@ class Imaging(abstract_dataset.AbstractDataset):
             An array describing the Point Spread Function kernel of the image.
         """
 
-        super().__init__(data=image, noise_map=noise_map, name=name)
+        super().__init__(
+            data=image, noise_map=noise_map, positions=positions, name=name
+        )
 
         self.psf = psf
 
@@ -99,9 +101,10 @@ class Imaging(abstract_dataset.AbstractDataset):
         noise_map_hdu=0,
         psf_path=None,
         psf_hdu=0,
+        positions_path=None,
         name=None,
     ):
-        """Factory for loading the imaging data_type from .fits files, as well as computing properties like the noise-map,
+        """Factory for loading the imaging data_type from .fits files, as well as computing properties like the noise map,
         exposure-time map, etc. from the imaging-data.
 
         This factory also includes a number of routines for converting the imaging-data from unit_label not supported by PyAutoLens \
@@ -149,7 +152,17 @@ class Imaging(abstract_dataset.AbstractDataset):
 
             psf = None
 
-        return Imaging(image=image, noise_map=noise_map, psf=psf, name=name)
+        if positions_path is not None:
+
+            positions = grids.GridCoordinates.from_file(file_path=positions_path)
+
+        else:
+
+            positions = None
+
+        return Imaging(
+            image=image, noise_map=noise_map, psf=psf, positions=positions, name=name
+        )
 
     def __array_finalize__(self, obj):
         if isinstance(obj, Imaging):
@@ -167,29 +180,33 @@ class MaskedImaging(abstract_dataset.AbstractMaskedDataset):
         self,
         imaging,
         mask,
+        grid_class=grids.GridIterate,
+        grid_inversion_class=grids.Grid,
+        fractional_accuracy=0.9999,
+        sub_steps=None,
+        pixel_scales_interp=None,
         psf_shape_2d=None,
-        pixel_scale_interpolation_grid=None,
         inversion_pixel_limit=None,
         inversion_uses_border=True,
         renormalize_psf=True,
     ):
         """
-        The lens dataset is the collection of data_type (image, noise-map, PSF), a mask, grid, convolver \
+        The lens dataset is the collection of data_type (image, noise map, PSF), a mask, grid, convolver \
         and other utilities that are used for modeling and fitting an image of a strong lens.
 
-        Whilst the image, noise-map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
+        Whilst the image, noise map, etc. are loaded in 2D, the lens dataset creates reduced 1D arrays of each \
         for lens calculations.
 
         Parameters
         ----------
         imaging: im.Imaging
-            The imaging data_type all in 2D (the image, noise-map, PSF, etc.)
+            The imaging data_type all in 2D (the image, noise map, PSF, etc.)
         mask: msk.Mask
             The 2D mask that is applied to the image.
         psf_shape_2d : (int, int)
             The shape of the PSF used for convolving model image generated using analytic light profiles. A smaller \
             shape will trim the PSF relative to the input image PSF, giving a faster analysis run-time.
-        pixel_scale_interpolation_grid : float
+        pixel_scales_interp : float
             If *True*, expensive to compute mass profile deflection angles will be computed on a sparse grid and \
             interpolated to the grid, sub and blurring grids.
         inversion_pixel_limit : int or None
@@ -200,19 +217,24 @@ class MaskedImaging(abstract_dataset.AbstractMaskedDataset):
         super().__init__(
             dataset=imaging,
             mask=mask,
-            pixel_scale_interpolation_grid=pixel_scale_interpolation_grid,
+            grid_class=grid_class,
+            grid_inversion_class=grid_inversion_class,
+            fractional_accuracy=fractional_accuracy,
+            sub_steps=sub_steps,
+            pixel_scales_interp=pixel_scales_interp,
             inversion_pixel_limit=inversion_pixel_limit,
             inversion_uses_border=inversion_uses_border,
         )
 
-        self.image = mask.mapping.array_stored_1d_from_array_2d(
-            array_2d=imaging.image.in_2d
-        )
-        self.noise_map = mask.mapping.array_stored_1d_from_array_2d(
-            array_2d=imaging.noise_map.in_2d
+        self.image = arrays.MaskedArray.manual_2d(
+            array=imaging.image.in_2d, mask=mask.mask_sub_1
         )
 
-        self.pixel_scale_interpolation_grid = pixel_scale_interpolation_grid
+        self.noise_map = arrays.MaskedArray.manual_2d(
+            array=imaging.noise_map.in_2d, mask=mask.mask_sub_1
+        )
+
+        self.pixel_scales_interp = pixel_scales_interp
 
         ### PSF TRIMMING + CONVOLVER ###
 
@@ -238,11 +260,6 @@ class MaskedImaging(abstract_dataset.AbstractMaskedDataset):
                     kernel_shape_2d=self.psf_shape_2d
                 )
 
-                if pixel_scale_interpolation_grid is not None:
-                    self.blurring_grid = self.blurring_grid.new_grid_with_interpolator(
-                        pixel_scale_interpolation_grid=self.pixel_scale_interpolation_grid
-                    )
-
         else:
 
             self.psf = None
@@ -258,6 +275,15 @@ class MaskedImaging(abstract_dataset.AbstractMaskedDataset):
     def signal_to_noise_map(self):
         return self.image / self.noise_map
 
+    def modify_image_and_noise_map(self, image, noise_map):
+
+        masked_imaging = copy.deepcopy(self)
+
+        masked_imaging.image = image
+        masked_imaging.noise_map = noise_map
+
+        return masked_imaging
+
 
 class SimulatorImaging:
     def __init__(
@@ -366,7 +392,7 @@ class SimulatorImaging:
 
         if np.isnan(noise_map).any():
             raise exc.DataException(
-                "The noise-map has NaN values in it. This suggests your exposure time and / or"
+                "The noise map has NaN values in it. This suggests your exposure time and / or"
                 "background sky levels are too low, creating signal counts at or close to 0.0."
             )
 
