@@ -3,8 +3,9 @@ import logging
 import numpy as np
 
 from autoarray import exc
-from autoarray.mask import geometry, mapping, regions
-from autoarray.util import array_util, mask_util
+from autoarray.structures import arrays
+from autoarray.mask import geometry, regions
+from autoarray.util import array_util, binning_util, mask_util
 
 logging.basicConfig()
 logger = logging.getLogger(__name__)
@@ -14,28 +15,33 @@ class Mask(np.ndarray):
 
     # noinspection PyUnusedLocal
     def __new__(
-        cls, mask_2d, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), *args, **kwargs
+        cls, mask, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), *args, **kwargs
     ):
-        """ A mask, which is applied to data to extract a set of unmasked image pixels (i.e. mask entry \
-        is *False* or 0) which are then fitted in an analysis.
+        """ A 2D mask, representing a uniform rectangular grid of neighboring rectangular pixels.
 
-        The mask retains the pixel scale of the array and has a centre and origin.
+        A mask s applied to an Array or Grid structure to signify which entries are used in calculations, where a
+        *False* entry signifies that the mask entry is unmasked and therefore is used in calculations.
+
+        The mask defines the geometry of the 2D uniform grid of pixels, for example their pixel scale and coordinate
+        origin. The 2D uniform grid may also be sub-gridded, whereby every pixel is sub-divided into a uniform gridd
+        of sub-pixels which are all used to perform calculations more accurate. See *Grid* for a detailed description
+        of sub-gridding.
 
         Parameters
         ----------
-        mask_2d: ndarray
-            An array of bools representing the mask.
-        pixel_scales: (float, float)
-            The arc-second to pixel conversion factor of each pixel.
+        mask: ndarray
+            The array of shape [total_y_pixels, total_x_pixels] containing the bools representing the mask, where
+            *False* signifies an entry is unmasked and used in calculations.
+        pixel_scales: (float, float) or float
+            The (y,x) arc-second to pixel conversion factors of every pixel. If this is input as a float, it is
+            converted to a (float, float) structure.
         origin : (float, float)
             The (y,x) arc-second origin of the mask's coordinate system.
-        centre : (float, float)
-            The (y,x) arc-second centre of the mask provided it is a standard geometric shape (e.g. a circle).
         """
         # noinspection PyArgumentList
 
-        mask_2d = mask_2d.astype("bool")
-        obj = mask_2d.view(cls)
+        mask = mask.astype("bool")
+        obj = mask.view(cls)
         obj.sub_size = sub_size
         obj.pixel_scales = pixel_scales
         obj.origin = origin
@@ -59,16 +65,20 @@ class Mask(np.ndarray):
             setattr(self, key, value)
         super(Mask, self).__setstate__(state[0:-1])
 
-    @property
-    def mapping(self):
-        return mapping.Mapping(mask=self)
-
     @property
     def geometry(self):
+        """The Geometry class contains methods describing the Mask's geometry, for example the Grid of unmasked
+        pixels.
+
+        See the Geometry class for a full description."""
         return geometry.Geometry(mask=self)
 
     @property
     def regions(self):
+        """The Region class contains methods describing regions on the Mask, for example the pixel indexes of Mask
+        pixels on its edge.
+
+        See the Region class for a full description."""
         return regions.Regions(mask=self)
 
     def __array_finalize__(self, obj):
@@ -84,40 +94,72 @@ class Mask(np.ndarray):
 
     @classmethod
     def manual(
-        cls, mask_2d, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), invert=False
+        cls, mask, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), invert=False
     ):
+        """Create a Mask (see *Mask.__new__*) by inputting the array values in 2D, for example:
 
-        if type(mask_2d) is list:
-            mask_2d = np.asarray(mask_2d).astype("bool")
+        mask=np.array([[False, False],
+                       [True, False]])
+
+        mask=[[False, False],
+               [True, False]]
+
+        Parameters
+        ----------
+        mask : np.ndarray or list
+            The bool values of the mask input as an ndarray of shape [total_y_pixels, total_x_pixels ]or a list of
+            lists.
+        pixel_scales : (float, float) or float
+            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
+            are converted to the format (float, float).
+        sub_size : int
+            The size (sub_size x sub_size) of each unmasked pixels sub-array.
+        origin : (float, float)
+            The origin of the array's mask.
+        invert : bool
+            If True, the input bools of the mask array are inverted such that previously unmasked entries containing
+            *False* become masked entries with *True*, and visa versa.
+        """
+        if type(mask) is list:
+            mask = np.asarray(mask).astype("bool")
 
         if invert:
-            mask_2d = np.invert(mask_2d)
+            mask = np.invert(mask)
 
         if type(pixel_scales) is float:
             pixel_scales = (pixel_scales, pixel_scales)
 
-        if len(mask_2d.shape) != 2:
-            raise exc.MaskException("The input mask_2d is not a two dimensional array")
+        if len(mask.shape) != 2:
+            raise exc.MaskException("The input mask is not a two dimensional array")
 
         return Mask(
-            mask_2d=mask_2d, pixel_scales=pixel_scales, sub_size=sub_size, origin=origin
+            mask=mask, pixel_scales=pixel_scales, sub_size=sub_size, origin=origin
         )
 
     @classmethod
     def unmasked(
         cls, shape_2d, pixel_scales=None, sub_size=1, origin=(0.0, 0.0), invert=False
     ):
-        """Setup a mask where all pixels are unmasked.
+        """Create a mask where all pixels are *False* and therefore unmasked.
 
         Parameters
         ----------
-        shape : (int, int)
-            The (y,x) shape of the mask in units of pixels.
-        pixel_scales : float or (float, float)
-            The arc-second to pixel conversion factor of each pixel.
+        mask : np.ndarray or list
+            The bool values of the mask input as an ndarray of shape [total_y_pixels, total_x_pixels ]or a list of
+            lists.
+        pixel_scales : (float, float) or float
+            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
+            are converted to the format (float, float).
+        sub_size : int
+            The size (sub_size x sub_size) of each unmasked pixels sub-array.
+        origin : (float, float)
+            The origin of the array's mask.
+        invert : bool
+            If True, the input bools of the mask array are inverted such that previously unmasked entries containing
+            *False* become masked entries with *True*, and visa versa.
         """
         return cls.manual(
-            mask_2d=np.full(shape=shape_2d, fill_value=False),
+            mask=np.full(shape=shape_2d, fill_value=False),
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
@@ -126,10 +168,16 @@ class Mask(np.ndarray):
 
     @property
     def sub_length(self):
+        """The total number of sub-pixels in a give pixel.
+
+        For example, a sub-size of 3x3 means every pixel has 9 sub-pixels."""
         return int(self.sub_size ** 2.0)
 
     @property
     def sub_fraction(self):
+        """The fraction of the area of a pixel every sub-pixel contains.
+
+        For example, a sub-size of 3x3 mean every pixel contains 1/9 the area."""
         return 1.0 / self.sub_length
 
     @classmethod
@@ -143,30 +191,39 @@ class Mask(np.ndarray):
         centre=(0.0, 0.0),
         invert=False,
     ):
-        """Setup a mask where unmasked pixels are within a circle of an input arc second radius and centre.
+        """Create a Mask (see *Mask.__new__*) where all *False* entries are within a circle of input radius and
+        centre.
 
         Parameters
         ----------
-        shape: (int, int)
+        shape_2d : (int, int)
             The (y,x) shape of the mask in units of pixels.
-        pixel_scales : (float, float)
-            The arc-second to pixel conversion factor of each pixel.
         radius : float
-            The radius (in arc seconds) of the circle within which pixels unmasked.
+            The radius (in scaled units) of the circle within which pixels are False and unmasked.
+        pixel_scales : (float, float) or float
+            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
+            are converted to the format (float, float).
+        sub_size : int
+            The size (sub_size x sub_size) of each unmasked pixels sub-array.
+        origin : (float, float)
+            The origin of the array's mask.
         centre: (float, float)
             The centre of the circle used to mask pixels.
+        invert : bool
+            If True, the input bools of the mask array are inverted such that previously unmasked entries containing
+            *False* become masked entries with *True*, and visa versa.
         """
 
         if type(pixel_scales) is not tuple:
             if type(pixel_scales) is float or int:
                 pixel_scales = (float(pixel_scales), float(pixel_scales))
 
-        mask_2d = mask_util.mask_2d_circular_from_shape_2d_pixel_scales_and_radius(
+        mask = mask_util.mask_circular_from(
             shape_2d=shape_2d, pixel_scales=pixel_scales, radius=radius, centre=centre
         )
 
         return cls.manual(
-            mask_2d=mask_2d,
+            mask=mask,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
@@ -185,28 +242,36 @@ class Mask(np.ndarray):
         centre=(0.0, 0.0),
         invert=False,
     ):
-        """Setup a mask where unmasked pixels are within an annulus of input inner and outer arc second radii and \
-         centre.
+        """Create a Mask (see *Mask.__new__*) where all *False* entries are within an annulus of input inner radius,
+         outer radius and centre.
 
         Parameters
         ----------
-        shape : (int, int)
+        shape_2d : (int, int)
             The (y,x) shape of the mask in units of pixels.
-        pixel_scales : (float, float)
-            The arc-second to pixel conversion factor of each pixel.
         inner_radius : float
-            The radius (in arc seconds) of the inner circle outside of which pixels are unmasked.
+            The inner radius (in scaled units) of the annulus within which pixels are False and unmasked.
         outer_radius : float
-            The radius (in arc seconds) of the outer circle within which pixels are unmasked.
+            The outer radius (in scaled units) of the annulus within which pixels are False and unmasked.
+        pixel_scales : (float, float) or float
+            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
+            are converted to the format (float, float).
+        sub_size : int
+            The size (sub_size x sub_size) of each unmasked pixels sub-array.
+        origin : (float, float)
+            The origin of the array's mask.
         centre: (float, float)
-            The centre of the annulus used to mask pixels.
+            The centre of the circle used to mask pixels.
+        invert : bool
+            If True, the input bools of the mask array are inverted such that previously unmasked entries containing
+            *False* become masked entries with *True*, and visa versa.
         """
 
         if type(pixel_scales) is not tuple:
             if type(pixel_scales) is float or int:
                 pixel_scales = (float(pixel_scales), float(pixel_scales))
 
-        mask_2d = mask_util.mask_2d_circular_annular_from_shape_2d_pixel_scales_and_radii(
+        mask = mask_util.mask_circular_annular_from(
             shape_2d=shape_2d,
             pixel_scales=pixel_scales,
             inner_radius=inner_radius,
@@ -215,7 +280,7 @@ class Mask(np.ndarray):
         )
 
         return cls.manual(
-            mask_2d=mask_2d,
+            mask=mask,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
@@ -235,35 +300,39 @@ class Mask(np.ndarray):
         centre=(0.0, 0.0),
         invert=False,
     ):
-        """Setup a mask where unmasked pixels are outside an annulus of input inner and outer arc second radii, but \
-        within a second outer radius, and at a given centre.
-
-        This mask there has two distinct unmasked regions (an inner circle and outer annulus), with an inner annulus \
-        of masked pixels.
+        """Create a Mask (see *Mask.__new__*) where all *False* entries are within an inner circle and second outer
+         circle, forming an inverse annulus.
 
         Parameters
         ----------
-        shape : (int, int)
+        shape_2d : (int, int)
             The (y,x) shape of the mask in units of pixels.
-        pixel_scales : (float, float)
-            The arc-second to pixel conversion factor of each pixel.
         inner_radius : float
-            The radius (in arc seconds) of the inner circle inside of which pixels are unmasked.
+            The inner radius (in scaled units) of the annulus within which pixels are False and unmasked.
         outer_radius : float
-            The radius (in arc seconds) of the outer circle within which pixels are masked and outside of which they \
-            are unmasked.
+            The first outer radius (in scaled units) of the annulus within which pixels are True and masked.
         outer_radius_2 : float
-            The radius (in arc seconds) of the second outer circle within which pixels are unmasked and outside of \
-            which they masked.
+            The second outer radius (in scaled units) of the annulus within which pixels are False and unmasked and
+            outside of which all entries are True and masked..
+        pixel_scales : (float, float) or float
+            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
+            are converted to the format (float, float).
+        sub_size : int
+            The size (sub_size x sub_size) of each unmasked pixels sub-array.
+        origin : (float, float)
+            The origin of the array's mask.
         centre: (float, float)
-            The centre of the anti-annulus used to mask pixels.
+            The centre of the circle used to mask pixels.
+        invert : bool
+            If True, the input bools of the mask array are inverted such that previously unmasked entries containing
+            *False* become masked entries with *True*, and visa versa.
         """
 
         if type(pixel_scales) is not tuple:
             if type(pixel_scales) is float or int:
                 pixel_scales = (float(pixel_scales), float(pixel_scales))
 
-        mask_2d = mask_util.mask_2d_circular_anti_annular_from_shape_2d_pixel_scales_and_radii(
+        mask = mask_util.mask_circular_anti_annular_from(
             shape_2d=shape_2d,
             pixel_scales=pixel_scales,
             inner_radius=inner_radius,
@@ -273,7 +342,7 @@ class Mask(np.ndarray):
         )
 
         return cls.manual(
-            mask_2d=mask_2d,
+            mask=mask,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
@@ -293,30 +362,38 @@ class Mask(np.ndarray):
         centre=(0.0, 0.0),
         invert=False,
     ):
-        """ Setup a mask where unmasked pixels are within an ellipse of an input arc second major-axis and centre.
+        """Create a Mask (see *Mask.__new__*) where all *False* entries are within a circle of input radius and
+        centre.
 
         Parameters
         ----------
-        shape: (int, int)
+        shape_2d : (int, int)
             The (y,x) shape of the mask in units of pixels.
-        pixel_scales : (float, float)
-            The arc-second to pixel conversion factor of each pixel.
         major_axis_radius : float
-            The major-axis (in arc seconds) of the ellipse within which pixels are unmasked.
+            The major-axis (in scaled units) of the ellipse within which pixels are unmasked.
         axis_ratio : float
             The axis-ratio of the ellipse within which pixels are unmasked.
         phi : float
             The rotation angle of the ellipse within which pixels are unmasked, (counter-clockwise from the positive \
              x-axis).
+        pixel_scales : (float, float) or float
+            The pixel conversion scale of a pixel in the y and x directions. If input as a float, the pixel_scales
+            are converted to the format (float, float).
+        sub_size : int
+            The size (sub_size x sub_size) of each unmasked pixels sub-array.
+        origin : (float, float)
+            The origin of the array's mask.
         centre: (float, float)
-            The centre of the ellipse used to mask pixels.
+            The centre of the circle used to mask pixels.
+        invert : bool
+            If True, the input bools of the mask array are inverted such that previously unmasked entries containing
+            *False* become masked entries with *True*, and visa versa.
         """
-
         if type(pixel_scales) is not tuple:
             if type(pixel_scales) is float or int:
                 pixel_scales = (float(pixel_scales), float(pixel_scales))
 
-        mask_2d = mask_util.mask_2d_elliptical_from_shape_2d_pixel_scales_and_radius(
+        mask = mask_util.mask_elliptical_from(
             shape_2d=shape_2d,
             pixel_scales=pixel_scales,
             major_axis_radius=major_axis_radius,
@@ -326,7 +403,7 @@ class Mask(np.ndarray):
         )
 
         return cls.manual(
-            mask_2d=mask_2d,
+            mask=mask,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
@@ -380,7 +457,7 @@ class Mask(np.ndarray):
             if type(pixel_scales) is float or int:
                 pixel_scales = (float(pixel_scales), float(pixel_scales))
 
-        mask_2d = mask_util.mask_2d_elliptical_annular_from_shape_2d_pixel_scales_and_radius(
+        mask = mask_util.mask_elliptical_annular_from(
             shape_2d=shape_2d,
             pixel_scales=pixel_scales,
             inner_major_axis_radius=inner_major_axis_radius,
@@ -393,7 +470,7 @@ class Mask(np.ndarray):
         )
 
         return cls.manual(
-            mask_2d=mask_2d,
+            mask=mask,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
@@ -412,12 +489,12 @@ class Mask(np.ndarray):
         invert=False,
     ):
 
-        mask_2d = mask_util.mask_2d_from_pixel_coordinates(
+        mask = mask_util.mask_via_pixel_coordinates_from(
             shape_2d=shape_2d, pixel_coordinates=pixel_coordinates, buffer=buffer
         )
 
         return cls.manual(
-            mask_2d=mask_2d,
+            mask=mask,
             pixel_scales=pixel_scales,
             sub_size=sub_size,
             origin=origin,
@@ -459,9 +536,7 @@ class Mask(np.ndarray):
         )
 
         if resized_mask_shape is not None:
-            mask = mask.mapping.resized_mask_from_new_shape(
-                new_shape=resized_mask_shape
-            )
+            mask = mask.resized_mask_from_new_shape(new_shape=resized_mask_shape)
 
         return mask
 
@@ -485,6 +560,10 @@ class Mask(np.ndarray):
     def pixels_in_mask(self):
         return int(np.size(self) - np.sum(self))
 
+    @property
+    def is_all_true(self):
+        return self.pixels_in_mask == 0
+
     @property
     def is_all_false(self):
         return self.pixels_in_mask == self.shape_2d[0] * self.shape_2d[1]
@@ -513,15 +592,134 @@ class Mask(np.ndarray):
             print("bleh")
 
     @property
-    def sub_mask_2d(self):
+    def sub_mask(self):
 
         sub_shape = (self.shape[0] * self.sub_size, self.shape[1] * self.sub_size)
 
-        return mask_util.mask_2d_from_shape_2d_and_mask_2d_index_for_mask_1d_index(
+        return mask_util.mask_via_shape_2d_and_mask_index_for_mask_1d_index_from(
             shape_2d=sub_shape,
-            mask_2d_index_for_mask_1d_index=self.regions._sub_mask_2d_index_for_sub_mask_1d_index,
+            mask_index_for_mask_1d_index=self.regions._sub_mask_index_for_sub_mask_1d_index,
         ).astype("bool")
 
     @property
     def mask_sub_1(self):
-        return self.mapping.mask_sub_1
+        return Mask(
+            mask=self, sub_size=1, pixel_scales=self.pixel_scales, origin=self.origin
+        )
+
+    @property
+    def edge_buffed_mask(self):
+        edge_buffed_mask = mask_util.buffed_mask_from(mask=self).astype("bool")
+        return Mask(
+            mask=edge_buffed_mask,
+            pixel_scales=self.pixel_scales,
+            sub_size=self.sub_size,
+            origin=self.origin,
+        )
+
+    def rescaled_mask_from_rescale_factor(self, rescale_factor):
+        rescaled_mask = mask_util.rescaled_mask_from(
+            mask=self, rescale_factor=rescale_factor
+        )
+        return Mask(
+            mask=rescaled_mask,
+            pixel_scales=self.pixel_scales,
+            sub_size=self.sub_size,
+            origin=self.origin,
+        )
+
+    def mask_new_sub_size_from_mask(self, mask, sub_size=1):
+        return Mask(
+            mask=mask,
+            sub_size=sub_size,
+            pixel_scales=self.pixel_scales,
+            origin=self.origin,
+        )
+
+    def binned_pixel_scales_from_bin_up_factor(self, bin_up_factor):
+        if self.pixel_scales is not None:
+            return (
+                self.pixel_scales[0] * bin_up_factor,
+                self.pixel_scales[1] * bin_up_factor,
+            )
+        else:
+            return None
+
+    def binned_mask_from_bin_up_factor(self, bin_up_factor):
+
+        binned_up_mask = binning_util.bin_mask(mask=self, bin_up_factor=bin_up_factor)
+
+        return Mask(
+            mask=binned_up_mask,
+            pixel_scales=self.binned_pixel_scales_from_bin_up_factor(
+                bin_up_factor=bin_up_factor
+            ),
+            sub_size=self.sub_size,
+            origin=self.origin,
+        )
+
+    def resized_mask_from_new_shape(self, new_shape):
+        """resized the array to a new shape and at a new origin.
+
+        Parameters
+        -----------
+        new_shape : (int, int)
+            The new two-dimensional shape of the array.
+        """
+
+        resized_mask = array_util.resized_array_2d_from_array_2d(
+            array_2d=self, resized_shape=new_shape
+        ).astype("bool")
+
+        return Mask(
+            mask=resized_mask,
+            pixel_scales=self.pixel_scales,
+            sub_size=self.sub_size,
+            origin=self.origin,
+        )
+
+    def trimmed_array_from_padded_array_and_image_shape(
+        self, padded_array, image_shape
+    ):
+        """ Map a padded 1D array of values to its original 2D array, trimming all edge values.
+
+        Parameters
+        -----------
+        padded_array : ndarray
+            A 1D array of values which were computed using a padded grid
+        """
+
+        pad_size_0 = self.shape[0] - image_shape[0]
+        pad_size_1 = self.shape[1] - image_shape[1]
+        trimmed_array = padded_array.in_2d_binned[
+            pad_size_0 // 2 : self.shape[0] - pad_size_0 // 2,
+            pad_size_1 // 2 : self.shape[1] - pad_size_1 // 2,
+        ]
+        return arrays.Array.manual_2d(
+            array=trimmed_array,
+            pixel_scales=self.pixel_scales,
+            sub_size=1,
+            origin=self.origin,
+        )
+
+    def unmasked_blurred_array_from_padded_array_psf_and_image_shape(
+        self, padded_array, psf, image_shape
+    ):
+        """For a padded grid and psf, compute an unmasked blurred image from an unmasked unblurred image.
+
+        This relies on using the lens dataset's padded-grid, which is a grid of (y,x) coordinates which extends over the \
+        entire image as opposed to just the masked region.
+
+        Parameters
+        ----------
+        psf : aa.Kernel
+            The PSF of the image used for convolution.
+        unmasked_image_1d : ndarray
+            The 1D unmasked image which is blurred.
+        """
+
+        blurred_image = psf.convolved_array_from_array(array=padded_array)
+
+        return self.trimmed_array_from_padded_array_and_image_shape(
+            padded_array=blurred_image, image_shape=image_shape
+        )
