@@ -1,5 +1,4 @@
 import numpy as np
-import scipy.spatial
 
 from autoarray import exc
 from autoarray.structures import grids
@@ -79,7 +78,9 @@ class Rectangular(Pixelization):
             hyper_image=hyper_image,
         )
 
-    def sparse_grid_from_grid(self, grid, hyper_image=None, seed=1):
+    def sparse_grid_from_grid(
+        self, grid, hyper_image=None, inversion_stochastic=False, seed=1
+    ):
         return None
 
 
@@ -129,7 +130,7 @@ class Voronoi(Pixelization):
 
         try:
             pixelization_grid = grids.GridVoronoi(
-                grid_1d=relocated_pixelization_grid,
+                grid=relocated_pixelization_grid,
                 nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.nearest_pixelization_1d_index_for_mask_1d_index,
             )
 
@@ -157,12 +158,14 @@ class VoronoiMagnification(Voronoi):
         self.shape = (int(shape[0]), int(shape[1]))
         self.pixels = self.shape[0] * self.shape[1]
 
-    def sparse_grid_from_grid(self, grid, hyper_image=None, seed=1):
-        sparse_grid = grids.SparseGrid.from_grid_and_unmasked_2d_grid_shape(
+    def sparse_grid_from_grid(
+        self, grid, hyper_image=None, inversion_stochastic=False, seed=1
+    ):
+        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
             grid=grid, unmasked_sparse_shape=self.shape
         )
 
-        return grids.GridIrregular(
+        return grids.GridVoronoi(
             grid=sparse_grid.sparse,
             nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
         )
@@ -189,14 +192,20 @@ class VoronoiBrightnessImage(Voronoi):
 
         return np.power(weight_map, self.weight_power)
 
-    def sparse_grid_from_grid(self, grid, hyper_image, seed=0):
+    def sparse_grid_from_grid(
+        self, grid, hyper_image, inversion_stochastic=False, seed=0
+    ):
         weight_map = self.weight_map_from_hyper_image(hyper_image=hyper_image)
 
-        sparse_grid = grids.SparseGrid.from_total_pixels_grid_and_weight_map(
-            total_pixels=self.pixels, grid=grid, weight_map=weight_map, seed=seed
+        sparse_grid = grids.GridSparse.from_total_pixels_grid_and_weight_map(
+            total_pixels=self.pixels,
+            grid=grid,
+            weight_map=weight_map,
+            seed=seed,
+            stochastic=inversion_stochastic,
         )
 
-        return grids.GridIrregular(
+        return grids.GridVoronoi(
             grid=sparse_grid.sparse,
             nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
         )
