@@ -9,7 +9,7 @@ class TestFitImaging:
     def test__image_and_model_are_identical__no_masking__check_values_are_correct(self):
 
         mask = aa.Mask.manual(
-            mask_2d=np.array([[False, False], [False, False]]),
+            mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
@@ -61,14 +61,14 @@ class TestFitImaging:
         assert fit.chi_squared == 0.0
         assert fit.reduced_chi_squared == 0.0
         assert fit.noise_normalization == np.sum(np.log(2 * np.pi * noise_map ** 2.0))
-        assert fit.likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
+        assert fit.log_likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
 
     def test__image_and_model_are_different__inclue_masking__check_values_are_correct(
         self
     ):
 
         mask = aa.Mask.manual(
-            mask_2d=np.array([[False, False], [True, False]]),
+            mask=np.array([[False, False], [True, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
@@ -116,14 +116,14 @@ class TestFitImaging:
         assert fit.chi_squared == 0.25
         assert fit.reduced_chi_squared == 0.25 / 3.0
         assert fit.noise_normalization == np.sum(np.log(2 * np.pi * noise_map ** 2.0))
-        assert fit.likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
+        assert fit.log_likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
 
     def test__image_and_model_are_identical__inversion_included__changes_certain_properties(
         self
     ):
 
         mask = aa.Mask.manual(
-            mask_2d=np.array([[False, False], [False, False]]),
+            mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
@@ -154,15 +154,15 @@ class TestFitImaging:
         assert fit.chi_squared == 0.0
         assert fit.reduced_chi_squared == 0.0
         assert fit.noise_normalization == np.sum(np.log(2 * np.pi * noise_map ** 2.0))
-        assert fit.likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
+        assert fit.log_likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
 
-        assert fit.likelihood_with_regularization == -0.5 * (
+        assert fit.log_likelihood_with_regularization == -0.5 * (
             fit.chi_squared + 2.0 + fit.noise_normalization
         )
-        assert fit.evidence == -0.5 * (
+        assert fit.log_evidence == -0.5 * (
             fit.chi_squared + 2.0 + 3.0 - 4.0 + fit.noise_normalization
         )
-        assert fit.figure_of_merit == fit.evidence
+        assert fit.figure_of_merit == fit.log_evidence
 
 
 class TestFitInterferometer:
@@ -173,7 +173,7 @@ class TestFitInterferometer:
         visibilities_mask = np.full(fill_value=False, shape=(2, 2))
 
         real_space_mask = aa.Mask.manual(
-            mask_2d=np.array([[False, False], [False, False]]),
+            mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
@@ -227,7 +227,7 @@ class TestFitInterferometer:
         assert fit.chi_squared == 0.0
         assert fit.reduced_chi_squared == 0.0
         assert fit.noise_normalization == np.sum(np.log(2 * np.pi * noise_map ** 2.0))
-        assert fit.likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
+        assert fit.log_likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
 
     def test__visibilities_and_model_are_different__no_masking__check_values_are_correct(
         self
@@ -236,7 +236,7 @@ class TestFitInterferometer:
         visibilities_mask = np.full(fill_value=False, shape=(2, 2))
 
         real_space_mask = aa.Mask.manual(
-            mask_2d=np.array([[False, False], [False, False]]),
+            mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
@@ -290,7 +290,7 @@ class TestFitInterferometer:
         assert fit.chi_squared == 0.25
         assert fit.reduced_chi_squared == 0.25 / 4.0
         assert fit.noise_normalization == np.sum(np.log(2 * np.pi * noise_map ** 2.0))
-        assert fit.likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
+        assert fit.log_likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
 
     def test__visibilities_and_model_are_identical__inversion_included__changes_certain_properties(
         self
@@ -299,7 +299,7 @@ class TestFitInterferometer:
         visibilities_mask = np.full(fill_value=False, shape=(2, 2))
 
         real_space_mask = aa.Mask.manual(
-            mask_2d=np.array([[False, False], [False, False]]),
+            mask=np.array([[False, False], [False, False]]),
             sub_size=1,
             pixel_scales=(1.0, 1.0),
         )
@@ -336,12 +336,12 @@ class TestFitInterferometer:
         assert fit.chi_squared == 0.0
         assert fit.reduced_chi_squared == 0.0
         assert fit.noise_normalization == np.sum(np.log(2 * np.pi * noise_map ** 2.0))
-        assert fit.likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
+        assert fit.log_likelihood == -0.5 * (fit.chi_squared + fit.noise_normalization)
 
-        assert fit.likelihood_with_regularization == -0.5 * (
+        assert fit.log_likelihood_with_regularization == -0.5 * (
             fit.chi_squared + 2.0 + fit.noise_normalization
         )
-        assert fit.evidence == -0.5 * (
+        assert fit.log_evidence == -0.5 * (
             fit.chi_squared + 2.0 + 3.0 - 4.0 + fit.noise_normalization
         )
-        assert fit.figure_of_merit == fit.evidence
+        assert fit.figure_of_merit == fit.log_evidence
