@@ -515,6 +515,26 @@ class TestAbstractPlotterAttributes:
         assert sub_plotter.liner.colors == ["r"]
         assert sub_plotter.liner.pointsize == 21
 
+    def test__array_overlayer__from_config_or_via_manual_input(self):
+
+        plotter = aplt.Plotter()
+
+        assert plotter.array_overlayer.alpha == 0.5
+
+        plotter = aplt.Plotter(array_overlayer=aplt.ArrayOverlayer(alpha=0.6))
+
+        assert plotter.array_overlayer.alpha == 0.6
+
+        sub_plotter = aplt.SubPlotter()
+
+        assert sub_plotter.array_overlayer.alpha == 0.7
+
+        sub_plotter = aplt.SubPlotter(
+            array_overlayer=aplt.ArrayOverlayer.sub(alpha=0.8)
+        )
+
+        assert sub_plotter.array_overlayer.alpha == 0.8
+
     def test__voronoi_drawer__from_config_or_via_manual_input(self):
 
         plotter = aplt.Plotter()
@@ -608,8 +628,9 @@ class TestAbstractPlotterPlots:
             array=array,
             mask=mask,
             grid=grid,
-            positions=[(-1.0, -1.0)],
-            lines=[(1.0, 1.0), (2.0, 2.0)],
+            positions=aa.GridCoordinates([(-1.0, -1.0)]),
+            lines=aa.GridCoordinates([(1.0, 1.0), (2.0, 2.0)]),
+            array_overlay=array,
             include_origin=True,
             include_border=True,
         )
@@ -624,8 +645,11 @@ class TestAbstractPlotterPlots:
             array=array,
             mask=mask,
             grid=grid,
-            positions=[[(1.0, 1.0), (2.0, 2.0)], [(-1.0, -1.0)]],
-            lines=[[(1.0, 1.0), (2.0, 2.0)], [(2.0, 4.0), (5.0, 6.0)]],
+            positions=aa.GridCoordinates([[(1.0, 1.0), (2.0, 2.0)], [(-1.0, -1.0)]]),
+            lines=aa.GridCoordinates(
+                [[(1.0, 1.0), (2.0, 2.0)], [(2.0, 4.0), (5.0, 6.0)]]
+            ),
+            array_overlay=array,
             include_origin=True,
             include_border=True,
         )
@@ -636,8 +660,9 @@ class TestAbstractPlotterPlots:
             array=array,
             mask=mask,
             grid=grid,
-            positions=[(-1.0, -1.0)],
-            lines=[(1.0, 1.0), (2.0, 2.0)],
+            positions=aa.GridCoordinates([(-1.0, -1.0)]),
+            lines=aa.GridCoordinates([(1.0, 1.0), (2.0, 2.0)]),
+            array_overlay=array,
             include=aplt.Include(origin=True, border=True),
             plotter=aplt.Plotter(
                 output=aplt.Output(path=plot_path, filename="array3", format="png")
@@ -693,7 +718,9 @@ class TestAbstractPlotterPlots:
             grid=grid,
             color_array=color_array,
             axis_limits=[-1.5, 1.5, -2.5, 2.5],
-            lines=[[(1.0, 1.0), (2.0, 2.0)], [(2.0, 4.0), (5.0, 6.0)]],
+            lines=aa.GridCoordinates(
+                [[(1.0, 1.0), (2.0, 2.0)], [(2.0, 4.0), (5.0, 6.0)]]
+            ),
             indexes=[0, 1, 2, 14],
             symmetric_around_centre=False,
         )
@@ -708,7 +735,9 @@ class TestAbstractPlotterPlots:
             grid=grid,
             color_array=color_array,
             axis_limits=[-1.5, 1.5, -2.5, 2.5],
-            lines=[[(1.0, 1.0), (2.0, 2.0)], [(2.0, 4.0), (5.0, 6.0)]],
+            lines=aa.GridCoordinates(
+                [[(1.0, 1.0), (2.0, 2.0)], [(2.0, 4.0), (5.0, 6.0)]]
+            ),
             indexes=[0, 1, 2, 14],
             symmetric_around_centre=True,
         )
@@ -719,7 +748,9 @@ class TestAbstractPlotterPlots:
             grid=grid,
             color_array=color_array,
             axis_limits=[-1.5, 1.5, -2.5, 2.5],
-            lines=[[(1.0, 1.0), (2.0, 2.0)], [(2.0, 4.0), (5.0, 6.0)]],
+            lines=aa.GridCoordinates(
+                [[(1.0, 1.0), (2.0, 2.0)], [(2.0, 4.0), (5.0, 6.0)]]
+            ),
             indexes=[0, 1, 2, 14],
             symmetric_around_centre=True,
             plotter=aplt.Plotter(
